@@ -10,15 +10,18 @@ module NetHTTPSpecHelper
     req = clazz.new("#{uri.path}#{uri.query ? '?' : ''}#{uri.query}", nil)
     options[:headers].each do |k,v|
       if v.is_a?(Array)
-        v.each_with_index do |v,i|
-          i == 0 ? (req[k] = v) : req.add_field(k, v)
+        v.each_with_index do |e,i|
+          i == 0 ? (req[k] = e) : req.add_field(k, e)
         end
       else
         req[k] = v
       end
     end if options[:headers]
 
-    req.basic_auth uri.user, uri.password if uri.user
+    if options[:basic_auth]
+      req.basic_auth(options[:basic_auth][0], options[:basic_auth][1])
+    end
+
     http = Net::HTTP.new(uri.host, uri.port)
     if uri.scheme == "https"
       http.use_ssl = true
@@ -28,21 +31,27 @@ module NetHTTPSpecHelper
       http.read_timeout = 60
     end
     http.verify_mode = OpenSSL::SSL::VERIFY_NONE
-    response = http.start {|http|
-      http.request(req, options[:body], &block)
+    response = http.start {|open_http|
+      open_http.request(req, options[:body], &block)
     }
     headers = {}
     response.each_header {|name, value| headers[name] = value}
     OpenStruct.new({
-      :body => response.body,
-      :headers => WebMock::Util::Headers.normalize_headers(headers),
-      :status => response.code,
-      :message => response.message
+      body: response.body,
+      headers: WebMock::Util::Headers.normalize_headers(headers),
+      status: response.code,
+      message: response.message
     })
   end
 
   def client_timeout_exception_class
-    Timeout::Error
+    if defined?(Net::OpenTimeout)
+      Net::OpenTimeout
+    elsif defined?(Net::HTTP::OpenTimeout)
+      Net::HTTP::OpenTimeout
+    else
+      Timeout::Error
+    end
   end
 
   def connection_refused_exception_class
