@@ -7,9 +7,9 @@ shared_context "complex cross-concern behaviors" do |*adapter_info|
     real_response = http_request(:get, webmock_server_url)
 
     stub_request(:get, webmock_server_url).to_return(
-      :status => recorded_response.status,
-      :body => recorded_response.body,
-      :headers => recorded_response.headers
+      status: recorded_response.status,
+      body: recorded_response.body,
+      headers: recorded_response.headers
     )
 
     played_back_response = http_request(:get, webmock_server_url)
@@ -20,12 +20,12 @@ shared_context "complex cross-concern behaviors" do |*adapter_info|
 
   let(:no_content_url) { 'http://httpstat.us/204' }
   [nil, ''].each do |stub_val|
-    it "returns the same value (nil or "") for a request stubbed as #{stub_val.inspect} that a real empty response has", :net_connect => true do
+    it "returns the same value (nil or "") for a request stubbed as #{stub_val.inspect} that a real empty response has", net_connect: true do
       unless http_library == :curb
         WebMock.allow_net_connect!
 
         real_response = http_request(:get, no_content_url)
-        stub_request(:get, no_content_url).to_return(:status => 204, :body => stub_val)
+        stub_request(:get, no_content_url).to_return(status: 204, body: stub_val)
         stubbed_response = http_request(:get, no_content_url)
 
         expect(stubbed_response.body).to eq(real_response.body)
